﻿// Rename all selected objects to be from left to right, based on there current horizontal order
// Version: 1.0.0
// This code is a quick hack. Feel free to edit as needed and keep us posted if you make valuable contributions

// Hacked by: Fontself team
// Contact: hello@fontself.com
// License: MIT 
// Copyright (c) 2020 Fontself

// UTILITIES

// For quick dialog UI generation: https://github.com/joonaspaakko/ScriptUI-Dialog-Builder-Joonas

// Trim space characters before & after a string
function trim (str) {
    return str.replace(/^\s+/,'').replace(/\s+$/,'');
}

// DIALOG
var dialog = new Window("dialog"); 
    dialog.text = "Rename Objects by Position"; 
    dialog.preferredSize.width = 340; 
    dialog.orientation = "column"; 
    dialog.alignChildren = ["center","top"]; 
    dialog.spacing = 10; 
    dialog.margins = 16; 

var statictext1 = dialog.add("group"); 
    statictext1.orientation = "column"; 
    statictext1.alignChildren = ["left","center"]; 
    statictext1.spacing = 0; 

    statictext1.add("statictext", undefined, "Assign specific names to the selected objects,", {name: "statictext1"}); 
    statictext1.add("statictext", undefined, "based on their horizontal position, from left to right.", {name: "statictext1"}); 
    statictext1.add("statictext", undefined, "", {name: "statictext1"}); 
    statictext1.add("statictext", undefined, "Type below a list of characters separated by commas:", {name: "statictext1"});

var strInput = dialog.add('edittext {properties: {name: "strInput"}}'); 
    strInput.alignment = ["fill","top"]; 

var statictext2 = dialog.add("group"); 
    statictext2.orientation = "column"; 
    statictext2.alignChildren = ["left","center"]; 
    statictext2.spacing = 0; 

    statictext2.add("statictext", undefined, "Supported extensions: .alt .lig .liga .dlig - like ffi.liga", {name: "statictext2"}); 
    statictext2.add("statictext", undefined, "Supported versioning: .altXX - like A.alt1, A.alt2", {name: "statictext2"}); 
    statictext2.add("statictext", undefined, "", {name: "statictext2"}); 


// GROUP1
var group1 = dialog.add("group", undefined, {name: "group1"}); 
    group1.orientation = "row"; 
    group1.alignChildren = ["center","center"]; 
    group1.spacing = 5; 
    group1.margins = 0; 
    group1.alignment = ["right","top"]; 

var butClose = group1.add("button", undefined, undefined, {name: "button1"}); 
    butClose.text = "Close"; 
    butClose.justify = "right"; 
    butClose.onClick = function(){
        dialog.close();
        return false;
    }

var butRename = group1.add("button", undefined, undefined, {name: "butRename"}); 
    butRename.text = "Rename Selection";
    butRename.onClick = function(){
        var chars = strInput.text.split(",");
      
        var selectedObjects = app.activeDocument.selection;
        
        var sortedObjects = selectedObjects.sort(function (a, b) {
          return a.position[0] - b.position[0];
        });

        //$.writeln("objs: " +sortedObjects.length);
        //$.writeln("chars: " +chars.length);
        //$.writeln("chars: " +chars);

        if (chars.length < sortedObjects.length) {
            alert("Too few characters to assign (type more or select fewer objects)");
        } else   
        if (chars.length > sortedObjects.length) {
            alert("Too many characters to assign (type fewer or select more objects)");
        } else {
            for (var i = 0; i < sortedObjects.length; i++) {
                //$.writeln(sortedObjects[i].name);
                //$.writeln(chars[i]);
                var cleanName = trim(chars[i]);
                sortedObjects[i].name = cleanName;
            }
            // Trick to refresh UI
            selectedObjects = app.activeDocument.selection;
            app.activeDocument.selection = [];
            app.activeDocument.selection = selectedObjects;
            
            //dialog.close();
            alert("Yes, objects have been renamed!");
        }
    
      return false;
    }
    
dialog.show();